summaryrefslogtreecommitdiffstats
diff options
context:
space:
mode:
authorMarc-André Lureau <marcandre.lureau@redhat.com>2015-06-19 12:19:55 +0200
committerMarc-André Lureau <marcandre.lureau@redhat.com>2015-10-24 18:02:49 +0200
commit9a2f0e64aeb4c7891244785e88b2b0cfa1d61742 (patch)
tree80f3436e99ee9a4c94edcad66096b89e4147756c
parentffa99afd6e4d354cdfae44cc43a2ca7ef056eb35 (diff)
downloadhqemu-9a2f0e64aeb4c7891244785e88b2b0cfa1d61742.zip
hqemu-9a2f0e64aeb4c7891244785e88b2b0cfa1d61742.tar.gz
ivshmem: simplify a bit the code
Use some more explicit variables to simplify the code. Signed-off-by: Marc-André Lureau <marcandre.lureau@redhat.com> Reviewed-by: Claudio Fontana <claudio.fontana@huawei.com>
-rw-r--r--hw/misc/ivshmem.c28
1 files changed, 14 insertions, 14 deletions
diff --git a/hw/misc/ivshmem.c b/hw/misc/ivshmem.c
index 6ee4881..c054e52 100644
--- a/hw/misc/ivshmem.c
+++ b/hw/misc/ivshmem.c
@@ -488,9 +488,10 @@ static void ivshmem_read(void *opaque, const uint8_t *buf, int size)
{
IVShmemState *s = opaque;
int incoming_fd;
- int guest_max_eventfd;
+ int new_eventfd;
long incoming_posn;
Error *err = NULL;
+ Peer *peer;
if (!fifo_update_and_get(s, buf, size,
&incoming_posn, sizeof(incoming_posn))) {
@@ -517,6 +518,8 @@ static void ivshmem_read(void *opaque, const uint8_t *buf, int size)
}
}
+ peer = &s->peers[incoming_posn];
+
if (incoming_fd == -1) {
/* if posn is positive and unseen before then this is our posn*/
if (incoming_posn >= 0 && s->vm_id == -1) {
@@ -564,27 +567,24 @@ static void ivshmem_read(void *opaque, const uint8_t *buf, int size)
return;
}
- /* each guest has an array of eventfds, and we keep track of how many
- * guests for each VM */
- guest_max_eventfd = s->peers[incoming_posn].nb_eventfds;
+ /* each peer has an associated array of eventfds, and we keep
+ * track of how many eventfds received so far */
+ /* get a new eventfd: */
+ new_eventfd = peer->nb_eventfds++;
/* this is an eventfd for a particular guest VM */
IVSHMEM_DPRINTF("eventfds[%ld][%d] = %d\n", incoming_posn,
- guest_max_eventfd, incoming_fd);
- event_notifier_init_fd(&s->peers[incoming_posn].eventfds[guest_max_eventfd],
- incoming_fd);
-
- /* increment count for particular guest */
- s->peers[incoming_posn].nb_eventfds++;
+ new_eventfd, incoming_fd);
+ event_notifier_init_fd(&peer->eventfds[new_eventfd], incoming_fd);
if (incoming_posn == s->vm_id) {
- s->eventfd_chr[guest_max_eventfd] = create_eventfd_chr_device(s,
- &s->peers[s->vm_id].eventfds[guest_max_eventfd],
- guest_max_eventfd);
+ s->eventfd_chr[new_eventfd] = create_eventfd_chr_device(s,
+ &s->peers[s->vm_id].eventfds[new_eventfd],
+ new_eventfd);
}
if (ivshmem_has_feature(s, IVSHMEM_IOEVENTFD)) {
- ivshmem_add_eventfd(s, incoming_posn, guest_max_eventfd);
+ ivshmem_add_eventfd(s, incoming_posn, new_eventfd);
}
}
OpenPOWER on IntegriCloud